import * as msRest from "@azure/ms-rest-js";
import * as msRestAzure from "@azure/ms-rest-azure-js";
import * as Models from "../models";
import { ComputeManagementClientContext } from "../computeManagementClientContext";
/** Class representing a DiskRestorePointOperations. */
export declare class DiskRestorePointOperations {
    private readonly client;
    /**
     * Create a DiskRestorePointOperations.
     * @param {ComputeManagementClientContext} client Reference to the service client.
     */
    constructor(client: ComputeManagementClientContext);
    /**
     * Get disk restorePoint resource
     * @param resourceGroupName The name of the resource group.
     * @param restorePointCollectionName The name of the restore point collection that the disk restore
     * point belongs.
     * @param vmRestorePointName The name of the vm restore point that the disk disk restore point
     * belongs.
     * @param diskRestorePointName The name of the disk restore point created.
     * @param [options] The optional parameters
     * @returns Promise<Models.DiskRestorePointGetResponse>
     */
    get(resourceGroupName: string, restorePointCollectionName: string, vmRestorePointName: string, diskRestorePointName: string, options?: msRest.RequestOptionsBase): Promise<Models.DiskRestorePointGetResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param restorePointCollectionName The name of the restore point collection that the disk restore
     * point belongs.
     * @param vmRestorePointName The name of the vm restore point that the disk disk restore point
     * belongs.
     * @param diskRestorePointName The name of the disk restore point created.
     * @param callback The callback
     */
    get(resourceGroupName: string, restorePointCollectionName: string, vmRestorePointName: string, diskRestorePointName: string, callback: msRest.ServiceCallback<Models.DiskRestorePoint>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param restorePointCollectionName The name of the restore point collection that the disk restore
     * point belongs.
     * @param vmRestorePointName The name of the vm restore point that the disk disk restore point
     * belongs.
     * @param diskRestorePointName The name of the disk restore point created.
     * @param options The optional parameters
     * @param callback The callback
     */
    get(resourceGroupName: string, restorePointCollectionName: string, vmRestorePointName: string, diskRestorePointName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.DiskRestorePoint>): void;
    /**
     * Lists diskRestorePoints under a vmRestorePoint.
     * @param resourceGroupName The name of the resource group.
     * @param restorePointCollectionName The name of the restore point collection that the disk restore
     * point belongs.
     * @param vmRestorePointName The name of the vm restore point that the disk disk restore point
     * belongs.
     * @param [options] The optional parameters
     * @returns Promise<Models.DiskRestorePointListByRestorePointResponse>
     */
    listByRestorePoint(resourceGroupName: string, restorePointCollectionName: string, vmRestorePointName: string, options?: msRest.RequestOptionsBase): Promise<Models.DiskRestorePointListByRestorePointResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param restorePointCollectionName The name of the restore point collection that the disk restore
     * point belongs.
     * @param vmRestorePointName The name of the vm restore point that the disk disk restore point
     * belongs.
     * @param callback The callback
     */
    listByRestorePoint(resourceGroupName: string, restorePointCollectionName: string, vmRestorePointName: string, callback: msRest.ServiceCallback<Models.DiskRestorePointList>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param restorePointCollectionName The name of the restore point collection that the disk restore
     * point belongs.
     * @param vmRestorePointName The name of the vm restore point that the disk disk restore point
     * belongs.
     * @param options The optional parameters
     * @param callback The callback
     */
    listByRestorePoint(resourceGroupName: string, restorePointCollectionName: string, vmRestorePointName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.DiskRestorePointList>): void;
    /**
     * Grants access to a diskRestorePoint.
     * @param resourceGroupName The name of the resource group.
     * @param restorePointCollectionName The name of the restore point collection that the disk restore
     * point belongs.
     * @param vmRestorePointName The name of the vm restore point that the disk disk restore point
     * belongs.
     * @param diskRestorePointName The name of the disk restore point created.
     * @param grantAccessData Access data object supplied in the body of the get disk access operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.DiskRestorePointGrantAccessResponse>
     */
    grantAccess(resourceGroupName: string, restorePointCollectionName: string, vmRestorePointName: string, diskRestorePointName: string, grantAccessData: Models.GrantAccessData, options?: msRest.RequestOptionsBase): Promise<Models.DiskRestorePointGrantAccessResponse>;
    /**
     * Revokes access to a diskRestorePoint.
     * @param resourceGroupName The name of the resource group.
     * @param restorePointCollectionName The name of the restore point collection that the disk restore
     * point belongs.
     * @param vmRestorePointName The name of the vm restore point that the disk disk restore point
     * belongs.
     * @param diskRestorePointName The name of the disk restore point created.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    revokeAccess(resourceGroupName: string, restorePointCollectionName: string, vmRestorePointName: string, diskRestorePointName: string, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * Grants access to a diskRestorePoint.
     * @param resourceGroupName The name of the resource group.
     * @param restorePointCollectionName The name of the restore point collection that the disk restore
     * point belongs.
     * @param vmRestorePointName The name of the vm restore point that the disk disk restore point
     * belongs.
     * @param diskRestorePointName The name of the disk restore point created.
     * @param grantAccessData Access data object supplied in the body of the get disk access operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginGrantAccess(resourceGroupName: string, restorePointCollectionName: string, vmRestorePointName: string, diskRestorePointName: string, grantAccessData: Models.GrantAccessData, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
    /**
     * Revokes access to a diskRestorePoint.
     * @param resourceGroupName The name of the resource group.
     * @param restorePointCollectionName The name of the restore point collection that the disk restore
     * point belongs.
     * @param vmRestorePointName The name of the vm restore point that the disk disk restore point
     * belongs.
     * @param diskRestorePointName The name of the disk restore point created.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginRevokeAccess(resourceGroupName: string, restorePointCollectionName: string, vmRestorePointName: string, diskRestorePointName: string, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
    /**
     * Lists diskRestorePoints under a vmRestorePoint.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.DiskRestorePointListByRestorePointNextResponse>
     */
    listByRestorePointNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.DiskRestorePointListByRestorePointNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listByRestorePointNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.DiskRestorePointList>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listByRestorePointNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.DiskRestorePointList>): void;
}
//# sourceMappingURL=diskRestorePointOperations.d.ts.map