/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */

import * as msRest from "@azure/ms-rest-js";
import * as Models from "../models";
import * as Mappers from "../models/communityGalleriesMappers";
import * as Parameters from "../models/parameters";
import { ComputeManagementClientContext } from "../computeManagementClientContext";

/** Class representing a CommunityGalleries. */
export class CommunityGalleries {
  private readonly client: ComputeManagementClientContext;

  /**
   * Create a CommunityGalleries.
   * @param {ComputeManagementClientContext} client Reference to the service client.
   */
  constructor(client: ComputeManagementClientContext) {
    this.client = client;
  }

  /**
   * Get a community gallery by gallery public name.
   * @param location Resource location.
   * @param publicGalleryName The public name of the community gallery.
   * @param [options] The optional parameters
   * @returns Promise<Models.CommunityGalleriesGetResponse>
   */
  get(location: string, publicGalleryName: string, options?: msRest.RequestOptionsBase): Promise<Models.CommunityGalleriesGetResponse>;
  /**
   * @param location Resource location.
   * @param publicGalleryName The public name of the community gallery.
   * @param callback The callback
   */
  get(location: string, publicGalleryName: string, callback: msRest.ServiceCallback<Models.CommunityGallery>): void;
  /**
   * @param location Resource location.
   * @param publicGalleryName The public name of the community gallery.
   * @param options The optional parameters
   * @param callback The callback
   */
  get(location: string, publicGalleryName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.CommunityGallery>): void;
  get(location: string, publicGalleryName: string, options?: msRest.RequestOptionsBase | msRest.ServiceCallback<Models.CommunityGallery>, callback?: msRest.ServiceCallback<Models.CommunityGallery>): Promise<Models.CommunityGalleriesGetResponse> {
    return this.client.sendOperationRequest(
      {
        location,
        publicGalleryName,
        options
      },
      getOperationSpec,
      callback) as Promise<Models.CommunityGalleriesGetResponse>;
  }
}

// Operation Specifications
const serializer = new msRest.Serializer(Mappers);
const getOperationSpec: msRest.OperationSpec = {
  httpMethod: "GET",
  path: "subscriptions/{subscriptionId}/providers/Microsoft.Compute/locations/{location}/communityGalleries/{publicGalleryName}",
  urlParameters: [
    Parameters.subscriptionId,
    Parameters.location0,
    Parameters.publicGalleryName
  ],
  queryParameters: [
    Parameters.apiVersion0
  ],
  headerParameters: [
    Parameters.acceptLanguage
  ],
  responses: {
    200: {
      bodyMapper: Mappers.CommunityGallery
    },
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};
