/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import { __assign } from "tslib";
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/applicationGatewaysMappers";
import * as Parameters from "../models/parameters";
/** Class representing a ApplicationGateways. */
var ApplicationGateways = /** @class */ (function () {
    /**
     * Create a ApplicationGateways.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    function ApplicationGateways(client) {
        this.client = client;
    }
    /**
     * Deletes the specified application gateway.
     * @param resourceGroupName The name of the resource group.
     * @param applicationGatewayName The name of the application gateway.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    ApplicationGateways.prototype.deleteMethod = function (resourceGroupName, applicationGatewayName, options) {
        return this.beginDeleteMethod(resourceGroupName, applicationGatewayName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    ApplicationGateways.prototype.get = function (resourceGroupName, applicationGatewayName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            applicationGatewayName: applicationGatewayName,
            options: options
        }, getOperationSpec, callback);
    };
    /**
     * Creates or updates the specified application gateway.
     * @param resourceGroupName The name of the resource group.
     * @param applicationGatewayName The name of the application gateway.
     * @param parameters Parameters supplied to the create or update application gateway operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.ApplicationGatewaysCreateOrUpdateResponse>
     */
    ApplicationGateways.prototype.createOrUpdate = function (resourceGroupName, applicationGatewayName, parameters, options) {
        return this.beginCreateOrUpdate(resourceGroupName, applicationGatewayName, parameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    ApplicationGateways.prototype.updateTags = function (resourceGroupName, applicationGatewayName, parameters, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            applicationGatewayName: applicationGatewayName,
            parameters: parameters,
            options: options
        }, updateTagsOperationSpec, callback);
    };
    ApplicationGateways.prototype.list = function (resourceGroupName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            options: options
        }, listOperationSpec, callback);
    };
    ApplicationGateways.prototype.listAll = function (options, callback) {
        return this.client.sendOperationRequest({
            options: options
        }, listAllOperationSpec, callback);
    };
    /**
     * Starts the specified application gateway.
     * @param resourceGroupName The name of the resource group.
     * @param applicationGatewayName The name of the application gateway.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    ApplicationGateways.prototype.start = function (resourceGroupName, applicationGatewayName, options) {
        return this.beginStart(resourceGroupName, applicationGatewayName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Stops the specified application gateway in a resource group.
     * @param resourceGroupName The name of the resource group.
     * @param applicationGatewayName The name of the application gateway.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    ApplicationGateways.prototype.stop = function (resourceGroupName, applicationGatewayName, options) {
        return this.beginStop(resourceGroupName, applicationGatewayName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Gets the backend health of the specified application gateway in a resource group.
     * @param resourceGroupName The name of the resource group.
     * @param applicationGatewayName The name of the application gateway.
     * @param [options] The optional parameters
     * @returns Promise<Models.ApplicationGatewaysBackendHealthResponse>
     */
    ApplicationGateways.prototype.backendHealth = function (resourceGroupName, applicationGatewayName, options) {
        return this.beginBackendHealth(resourceGroupName, applicationGatewayName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Gets the backend health for given combination of backend pool and http setting of the specified
     * application gateway in a resource group.
     * @param resourceGroupName The name of the resource group.
     * @param applicationGatewayName The name of the application gateway.
     * @param probeRequest Request body for on-demand test probe operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.ApplicationGatewaysBackendHealthOnDemandResponse>
     */
    ApplicationGateways.prototype.backendHealthOnDemand = function (resourceGroupName, applicationGatewayName, probeRequest, options) {
        return this.beginBackendHealthOnDemand(resourceGroupName, applicationGatewayName, probeRequest, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    ApplicationGateways.prototype.listAvailableServerVariables = function (options, callback) {
        return this.client.sendOperationRequest({
            options: options
        }, listAvailableServerVariablesOperationSpec, callback);
    };
    ApplicationGateways.prototype.listAvailableRequestHeaders = function (options, callback) {
        return this.client.sendOperationRequest({
            options: options
        }, listAvailableRequestHeadersOperationSpec, callback);
    };
    ApplicationGateways.prototype.listAvailableResponseHeaders = function (options, callback) {
        return this.client.sendOperationRequest({
            options: options
        }, listAvailableResponseHeadersOperationSpec, callback);
    };
    ApplicationGateways.prototype.listAvailableWafRuleSets = function (options, callback) {
        return this.client.sendOperationRequest({
            options: options
        }, listAvailableWafRuleSetsOperationSpec, callback);
    };
    ApplicationGateways.prototype.listAvailableSslOptions = function (options, callback) {
        return this.client.sendOperationRequest({
            options: options
        }, listAvailableSslOptionsOperationSpec, callback);
    };
    ApplicationGateways.prototype.listAvailableSslPredefinedPolicies = function (options, callback) {
        return this.client.sendOperationRequest({
            options: options
        }, listAvailableSslPredefinedPoliciesOperationSpec, callback);
    };
    ApplicationGateways.prototype.getSslPredefinedPolicy = function (predefinedPolicyName, options, callback) {
        return this.client.sendOperationRequest({
            predefinedPolicyName: predefinedPolicyName,
            options: options
        }, getSslPredefinedPolicyOperationSpec, callback);
    };
    /**
     * Deletes the specified application gateway.
     * @param resourceGroupName The name of the resource group.
     * @param applicationGatewayName The name of the application gateway.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    ApplicationGateways.prototype.beginDeleteMethod = function (resourceGroupName, applicationGatewayName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            applicationGatewayName: applicationGatewayName,
            options: options
        }, beginDeleteMethodOperationSpec, options);
    };
    /**
     * Creates or updates the specified application gateway.
     * @param resourceGroupName The name of the resource group.
     * @param applicationGatewayName The name of the application gateway.
     * @param parameters Parameters supplied to the create or update application gateway operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    ApplicationGateways.prototype.beginCreateOrUpdate = function (resourceGroupName, applicationGatewayName, parameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            applicationGatewayName: applicationGatewayName,
            parameters: parameters,
            options: options
        }, beginCreateOrUpdateOperationSpec, options);
    };
    /**
     * Starts the specified application gateway.
     * @param resourceGroupName The name of the resource group.
     * @param applicationGatewayName The name of the application gateway.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    ApplicationGateways.prototype.beginStart = function (resourceGroupName, applicationGatewayName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            applicationGatewayName: applicationGatewayName,
            options: options
        }, beginStartOperationSpec, options);
    };
    /**
     * Stops the specified application gateway in a resource group.
     * @param resourceGroupName The name of the resource group.
     * @param applicationGatewayName The name of the application gateway.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    ApplicationGateways.prototype.beginStop = function (resourceGroupName, applicationGatewayName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            applicationGatewayName: applicationGatewayName,
            options: options
        }, beginStopOperationSpec, options);
    };
    /**
     * Gets the backend health of the specified application gateway in a resource group.
     * @param resourceGroupName The name of the resource group.
     * @param applicationGatewayName The name of the application gateway.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    ApplicationGateways.prototype.beginBackendHealth = function (resourceGroupName, applicationGatewayName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            applicationGatewayName: applicationGatewayName,
            options: options
        }, beginBackendHealthOperationSpec, options);
    };
    /**
     * Gets the backend health for given combination of backend pool and http setting of the specified
     * application gateway in a resource group.
     * @param resourceGroupName The name of the resource group.
     * @param applicationGatewayName The name of the application gateway.
     * @param probeRequest Request body for on-demand test probe operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    ApplicationGateways.prototype.beginBackendHealthOnDemand = function (resourceGroupName, applicationGatewayName, probeRequest, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            applicationGatewayName: applicationGatewayName,
            probeRequest: probeRequest,
            options: options
        }, beginBackendHealthOnDemandOperationSpec, options);
    };
    ApplicationGateways.prototype.listNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listNextOperationSpec, callback);
    };
    ApplicationGateways.prototype.listAllNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listAllNextOperationSpec, callback);
    };
    ApplicationGateways.prototype.listAvailableSslPredefinedPoliciesNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listAvailableSslPredefinedPoliciesNextOperationSpec, callback);
    };
    return ApplicationGateways;
}());
export { ApplicationGateways };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var getOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/applicationGateways/{applicationGatewayName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.applicationGatewayName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ApplicationGateway
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var updateTagsOperationSpec = {
    httpMethod: "PATCH",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/applicationGateways/{applicationGatewayName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.applicationGatewayName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.TagsObject), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.ApplicationGateway
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/applicationGateways",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ApplicationGatewayListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listAllOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/providers/Microsoft.Network/applicationGateways",
    urlParameters: [
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ApplicationGatewayListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listAvailableServerVariablesOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/providers/Microsoft.Network/applicationGatewayAvailableServerVariables",
    urlParameters: [
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: {
                serializedName: "parsedResponse",
                type: {
                    name: "Sequence",
                    element: {
                        type: {
                            name: "String"
                        }
                    }
                }
            }
        },
        default: {
            bodyMapper: Mappers.ErrorModel
        }
    },
    serializer: serializer
};
var listAvailableRequestHeadersOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/providers/Microsoft.Network/applicationGatewayAvailableRequestHeaders",
    urlParameters: [
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: {
                serializedName: "parsedResponse",
                type: {
                    name: "Sequence",
                    element: {
                        type: {
                            name: "String"
                        }
                    }
                }
            }
        },
        default: {
            bodyMapper: Mappers.ErrorModel
        }
    },
    serializer: serializer
};
var listAvailableResponseHeadersOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/providers/Microsoft.Network/applicationGatewayAvailableResponseHeaders",
    urlParameters: [
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: {
                serializedName: "parsedResponse",
                type: {
                    name: "Sequence",
                    element: {
                        type: {
                            name: "String"
                        }
                    }
                }
            }
        },
        default: {
            bodyMapper: Mappers.ErrorModel
        }
    },
    serializer: serializer
};
var listAvailableWafRuleSetsOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/providers/Microsoft.Network/applicationGatewayAvailableWafRuleSets",
    urlParameters: [
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ApplicationGatewayAvailableWafRuleSetsResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listAvailableSslOptionsOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/providers/Microsoft.Network/applicationGatewayAvailableSslOptions/default",
    urlParameters: [
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ApplicationGatewayAvailableSslOptions
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listAvailableSslPredefinedPoliciesOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/providers/Microsoft.Network/applicationGatewayAvailableSslOptions/default/predefinedPolicies",
    urlParameters: [
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ApplicationGatewayAvailableSslPredefinedPolicies
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var getSslPredefinedPolicyOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/providers/Microsoft.Network/applicationGatewayAvailableSslOptions/default/predefinedPolicies/{predefinedPolicyName}",
    urlParameters: [
        Parameters.subscriptionId,
        Parameters.predefinedPolicyName
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ApplicationGatewaySslPredefinedPolicy
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginDeleteMethodOperationSpec = {
    httpMethod: "DELETE",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/applicationGateways/{applicationGatewayName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.applicationGatewayName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {},
        202: {},
        204: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginCreateOrUpdateOperationSpec = {
    httpMethod: "PUT",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/applicationGateways/{applicationGatewayName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.applicationGatewayName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.ApplicationGateway), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.ApplicationGateway
        },
        201: {
            bodyMapper: Mappers.ApplicationGateway
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginStartOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/applicationGateways/{applicationGatewayName}/start",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.applicationGatewayName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {},
        202: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginStopOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/applicationGateways/{applicationGatewayName}/stop",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.applicationGatewayName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {},
        202: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginBackendHealthOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/applicationGateways/{applicationGatewayName}/backendhealth",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.applicationGatewayName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0,
        Parameters.expand
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ApplicationGatewayBackendHealth
        },
        202: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginBackendHealthOnDemandOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/applicationGateways/{applicationGatewayName}/getBackendHealthOnDemand",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.applicationGatewayName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0,
        Parameters.expand
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "probeRequest",
        mapper: __assign(__assign({}, Mappers.ApplicationGatewayOnDemandProbe), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.ApplicationGatewayBackendHealthOnDemand
        },
        202: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ApplicationGatewayListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listAllNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ApplicationGatewayListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listAvailableSslPredefinedPoliciesNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ApplicationGatewayAvailableSslPredefinedPolicies
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
//# sourceMappingURL=applicationGateways.js.map