import * as msRest from "@azure/ms-rest-js";
import * as Models from "../models";
import { NetworkManagementClientContext } from "../networkManagementClientContext";
/** Class representing a FirewallPolicyIdpsSignaturesOverrides. */
export declare class FirewallPolicyIdpsSignaturesOverrides {
    private readonly client;
    /**
     * Create a FirewallPolicyIdpsSignaturesOverrides.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    constructor(client: NetworkManagementClientContext);
    /**
     * Will update the status of policy's signature overrides for IDPS
     * @param parameters Will contain all properties of the object to put
     * @param resourceGroupName The name of the resource group.
     * @param firewallPolicyName The name of the Firewall Policy.
     * @param [options] The optional parameters
     * @returns Promise<Models.FirewallPolicyIdpsSignaturesOverridesPatchResponse>
     */
    patch(parameters: Models.SignaturesOverrides, resourceGroupName: string, firewallPolicyName: string, options?: msRest.RequestOptionsBase): Promise<Models.FirewallPolicyIdpsSignaturesOverridesPatchResponse>;
    /**
     * @param parameters Will contain all properties of the object to put
     * @param resourceGroupName The name of the resource group.
     * @param firewallPolicyName The name of the Firewall Policy.
     * @param callback The callback
     */
    patch(parameters: Models.SignaturesOverrides, resourceGroupName: string, firewallPolicyName: string, callback: msRest.ServiceCallback<Models.SignaturesOverrides>): void;
    /**
     * @param parameters Will contain all properties of the object to put
     * @param resourceGroupName The name of the resource group.
     * @param firewallPolicyName The name of the Firewall Policy.
     * @param options The optional parameters
     * @param callback The callback
     */
    patch(parameters: Models.SignaturesOverrides, resourceGroupName: string, firewallPolicyName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.SignaturesOverrides>): void;
    /**
     * Will override/create a new signature overrides for the policy's IDPS
     * @param parameters Will contain all properties of the object to put
     * @param resourceGroupName The name of the resource group.
     * @param firewallPolicyName The name of the Firewall Policy.
     * @param [options] The optional parameters
     * @returns Promise<Models.FirewallPolicyIdpsSignaturesOverridesPutResponse>
     */
    put(parameters: Models.SignaturesOverrides, resourceGroupName: string, firewallPolicyName: string, options?: msRest.RequestOptionsBase): Promise<Models.FirewallPolicyIdpsSignaturesOverridesPutResponse>;
    /**
     * @param parameters Will contain all properties of the object to put
     * @param resourceGroupName The name of the resource group.
     * @param firewallPolicyName The name of the Firewall Policy.
     * @param callback The callback
     */
    put(parameters: Models.SignaturesOverrides, resourceGroupName: string, firewallPolicyName: string, callback: msRest.ServiceCallback<Models.SignaturesOverrides>): void;
    /**
     * @param parameters Will contain all properties of the object to put
     * @param resourceGroupName The name of the resource group.
     * @param firewallPolicyName The name of the Firewall Policy.
     * @param options The optional parameters
     * @param callback The callback
     */
    put(parameters: Models.SignaturesOverrides, resourceGroupName: string, firewallPolicyName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.SignaturesOverrides>): void;
    /**
     * Returns all signatures overrides for a specific policy.
     * @param resourceGroupName The name of the resource group.
     * @param firewallPolicyName The name of the Firewall Policy.
     * @param [options] The optional parameters
     * @returns Promise<Models.FirewallPolicyIdpsSignaturesOverridesGetResponse>
     */
    get(resourceGroupName: string, firewallPolicyName: string, options?: msRest.RequestOptionsBase): Promise<Models.FirewallPolicyIdpsSignaturesOverridesGetResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param firewallPolicyName The name of the Firewall Policy.
     * @param callback The callback
     */
    get(resourceGroupName: string, firewallPolicyName: string, callback: msRest.ServiceCallback<Models.SignaturesOverrides>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param firewallPolicyName The name of the Firewall Policy.
     * @param options The optional parameters
     * @param callback The callback
     */
    get(resourceGroupName: string, firewallPolicyName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.SignaturesOverrides>): void;
    /**
     * Returns all signatures overrides objects for a specific policy as a list containing a single
     * value.
     * @param resourceGroupName The name of the resource group.
     * @param firewallPolicyName The name of the Firewall Policy.
     * @param [options] The optional parameters
     * @returns Promise<Models.FirewallPolicyIdpsSignaturesOverridesListResponse>
     */
    list(resourceGroupName: string, firewallPolicyName: string, options?: msRest.RequestOptionsBase): Promise<Models.FirewallPolicyIdpsSignaturesOverridesListResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param firewallPolicyName The name of the Firewall Policy.
     * @param callback The callback
     */
    list(resourceGroupName: string, firewallPolicyName: string, callback: msRest.ServiceCallback<Models.SignaturesOverridesList>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param firewallPolicyName The name of the Firewall Policy.
     * @param options The optional parameters
     * @param callback The callback
     */
    list(resourceGroupName: string, firewallPolicyName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.SignaturesOverridesList>): void;
}
//# sourceMappingURL=firewallPolicyIdpsSignaturesOverrides.d.ts.map