import * as msRest from "@azure/ms-rest-js";
import * as msRestAzure from "@azure/ms-rest-azure-js";
import * as Models from "../models";
import { NetworkManagementClientContext } from "../networkManagementClientContext";
/** Class representing a FirewallPolicyRuleCollectionGroups. */
export declare class FirewallPolicyRuleCollectionGroups {
    private readonly client;
    /**
     * Create a FirewallPolicyRuleCollectionGroups.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    constructor(client: NetworkManagementClientContext);
    /**
     * Deletes the specified FirewallPolicyRuleCollectionGroup.
     * @param resourceGroupName The name of the resource group.
     * @param firewallPolicyName The name of the Firewall Policy.
     * @param ruleCollectionGroupName The name of the FirewallPolicyRuleCollectionGroup.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    deleteMethod(resourceGroupName: string, firewallPolicyName: string, ruleCollectionGroupName: string, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * Gets the specified FirewallPolicyRuleCollectionGroup.
     * @param resourceGroupName The name of the resource group.
     * @param firewallPolicyName The name of the Firewall Policy.
     * @param ruleCollectionGroupName The name of the FirewallPolicyRuleCollectionGroup.
     * @param [options] The optional parameters
     * @returns Promise<Models.FirewallPolicyRuleCollectionGroupsGetResponse>
     */
    get(resourceGroupName: string, firewallPolicyName: string, ruleCollectionGroupName: string, options?: msRest.RequestOptionsBase): Promise<Models.FirewallPolicyRuleCollectionGroupsGetResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param firewallPolicyName The name of the Firewall Policy.
     * @param ruleCollectionGroupName The name of the FirewallPolicyRuleCollectionGroup.
     * @param callback The callback
     */
    get(resourceGroupName: string, firewallPolicyName: string, ruleCollectionGroupName: string, callback: msRest.ServiceCallback<Models.FirewallPolicyRuleCollectionGroup>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param firewallPolicyName The name of the Firewall Policy.
     * @param ruleCollectionGroupName The name of the FirewallPolicyRuleCollectionGroup.
     * @param options The optional parameters
     * @param callback The callback
     */
    get(resourceGroupName: string, firewallPolicyName: string, ruleCollectionGroupName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.FirewallPolicyRuleCollectionGroup>): void;
    /**
     * Creates or updates the specified FirewallPolicyRuleCollectionGroup.
     * @param resourceGroupName The name of the resource group.
     * @param firewallPolicyName The name of the Firewall Policy.
     * @param ruleCollectionGroupName The name of the FirewallPolicyRuleCollectionGroup.
     * @param parameters Parameters supplied to the create or update FirewallPolicyRuleCollectionGroup
     * operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.FirewallPolicyRuleCollectionGroupsCreateOrUpdateResponse>
     */
    createOrUpdate(resourceGroupName: string, firewallPolicyName: string, ruleCollectionGroupName: string, parameters: Models.FirewallPolicyRuleCollectionGroup, options?: msRest.RequestOptionsBase): Promise<Models.FirewallPolicyRuleCollectionGroupsCreateOrUpdateResponse>;
    /**
     * Lists all FirewallPolicyRuleCollectionGroups in a FirewallPolicy resource.
     * @param resourceGroupName The name of the resource group.
     * @param firewallPolicyName The name of the Firewall Policy.
     * @param [options] The optional parameters
     * @returns Promise<Models.FirewallPolicyRuleCollectionGroupsListResponse>
     */
    list(resourceGroupName: string, firewallPolicyName: string, options?: msRest.RequestOptionsBase): Promise<Models.FirewallPolicyRuleCollectionGroupsListResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param firewallPolicyName The name of the Firewall Policy.
     * @param callback The callback
     */
    list(resourceGroupName: string, firewallPolicyName: string, callback: msRest.ServiceCallback<Models.FirewallPolicyRuleCollectionGroupListResult>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param firewallPolicyName The name of the Firewall Policy.
     * @param options The optional parameters
     * @param callback The callback
     */
    list(resourceGroupName: string, firewallPolicyName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.FirewallPolicyRuleCollectionGroupListResult>): void;
    /**
     * Deletes the specified FirewallPolicyRuleCollectionGroup.
     * @param resourceGroupName The name of the resource group.
     * @param firewallPolicyName The name of the Firewall Policy.
     * @param ruleCollectionGroupName The name of the FirewallPolicyRuleCollectionGroup.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginDeleteMethod(resourceGroupName: string, firewallPolicyName: string, ruleCollectionGroupName: string, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
    /**
     * Creates or updates the specified FirewallPolicyRuleCollectionGroup.
     * @param resourceGroupName The name of the resource group.
     * @param firewallPolicyName The name of the Firewall Policy.
     * @param ruleCollectionGroupName The name of the FirewallPolicyRuleCollectionGroup.
     * @param parameters Parameters supplied to the create or update FirewallPolicyRuleCollectionGroup
     * operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginCreateOrUpdate(resourceGroupName: string, firewallPolicyName: string, ruleCollectionGroupName: string, parameters: Models.FirewallPolicyRuleCollectionGroup, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
    /**
     * Lists all FirewallPolicyRuleCollectionGroups in a FirewallPolicy resource.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.FirewallPolicyRuleCollectionGroupsListNextResponse>
     */
    listNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.FirewallPolicyRuleCollectionGroupsListNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.FirewallPolicyRuleCollectionGroupListResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.FirewallPolicyRuleCollectionGroupListResult>): void;
}
//# sourceMappingURL=firewallPolicyRuleCollectionGroups.d.ts.map