/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import { __assign } from "tslib";
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/inboundNatRulesMappers";
import * as Parameters from "../models/parameters";
/** Class representing a InboundNatRules. */
var InboundNatRules = /** @class */ (function () {
    /**
     * Create a InboundNatRules.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    function InboundNatRules(client) {
        this.client = client;
    }
    InboundNatRules.prototype.list = function (resourceGroupName, loadBalancerName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            loadBalancerName: loadBalancerName,
            options: options
        }, listOperationSpec, callback);
    };
    /**
     * Deletes the specified load balancer inbound NAT rule.
     * @param resourceGroupName The name of the resource group.
     * @param loadBalancerName The name of the load balancer.
     * @param inboundNatRuleName The name of the inbound NAT rule.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    InboundNatRules.prototype.deleteMethod = function (resourceGroupName, loadBalancerName, inboundNatRuleName, options) {
        return this.beginDeleteMethod(resourceGroupName, loadBalancerName, inboundNatRuleName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    InboundNatRules.prototype.get = function (resourceGroupName, loadBalancerName, inboundNatRuleName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            loadBalancerName: loadBalancerName,
            inboundNatRuleName: inboundNatRuleName,
            options: options
        }, getOperationSpec, callback);
    };
    /**
     * Creates or updates a load balancer inbound NAT rule.
     * @param resourceGroupName The name of the resource group.
     * @param loadBalancerName The name of the load balancer.
     * @param inboundNatRuleName The name of the inbound NAT rule.
     * @param inboundNatRuleParameters Parameters supplied to the create or update inbound NAT rule
     * operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.InboundNatRulesCreateOrUpdateResponse>
     */
    InboundNatRules.prototype.createOrUpdate = function (resourceGroupName, loadBalancerName, inboundNatRuleName, inboundNatRuleParameters, options) {
        return this.beginCreateOrUpdate(resourceGroupName, loadBalancerName, inboundNatRuleName, inboundNatRuleParameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Deletes the specified load balancer inbound NAT rule.
     * @param resourceGroupName The name of the resource group.
     * @param loadBalancerName The name of the load balancer.
     * @param inboundNatRuleName The name of the inbound NAT rule.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    InboundNatRules.prototype.beginDeleteMethod = function (resourceGroupName, loadBalancerName, inboundNatRuleName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            loadBalancerName: loadBalancerName,
            inboundNatRuleName: inboundNatRuleName,
            options: options
        }, beginDeleteMethodOperationSpec, options);
    };
    /**
     * Creates or updates a load balancer inbound NAT rule.
     * @param resourceGroupName The name of the resource group.
     * @param loadBalancerName The name of the load balancer.
     * @param inboundNatRuleName The name of the inbound NAT rule.
     * @param inboundNatRuleParameters Parameters supplied to the create or update inbound NAT rule
     * operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    InboundNatRules.prototype.beginCreateOrUpdate = function (resourceGroupName, loadBalancerName, inboundNatRuleName, inboundNatRuleParameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            loadBalancerName: loadBalancerName,
            inboundNatRuleName: inboundNatRuleName,
            inboundNatRuleParameters: inboundNatRuleParameters,
            options: options
        }, beginCreateOrUpdateOperationSpec, options);
    };
    InboundNatRules.prototype.listNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listNextOperationSpec, callback);
    };
    return InboundNatRules;
}());
export { InboundNatRules };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var listOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/loadBalancers/{loadBalancerName}/inboundNatRules",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.loadBalancerName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.InboundNatRuleListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var getOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/loadBalancers/{loadBalancerName}/inboundNatRules/{inboundNatRuleName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.loadBalancerName,
        Parameters.inboundNatRuleName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0,
        Parameters.expand
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.InboundNatRule
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginDeleteMethodOperationSpec = {
    httpMethod: "DELETE",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/loadBalancers/{loadBalancerName}/inboundNatRules/{inboundNatRuleName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.loadBalancerName,
        Parameters.inboundNatRuleName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {},
        202: {},
        204: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginCreateOrUpdateOperationSpec = {
    httpMethod: "PUT",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/loadBalancers/{loadBalancerName}/inboundNatRules/{inboundNatRuleName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.loadBalancerName,
        Parameters.inboundNatRuleName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "inboundNatRuleParameters",
        mapper: __assign(__assign({}, Mappers.InboundNatRule), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.InboundNatRule
        },
        201: {
            bodyMapper: Mappers.InboundNatRule
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.InboundNatRuleListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
//# sourceMappingURL=inboundNatRules.js.map