/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import { __assign } from "tslib";
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/loadBalancersMappers";
import * as Parameters from "../models/parameters";
/** Class representing a LoadBalancers. */
var LoadBalancers = /** @class */ (function () {
    /**
     * Create a LoadBalancers.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    function LoadBalancers(client) {
        this.client = client;
    }
    /**
     * Deletes the specified load balancer.
     * @param resourceGroupName The name of the resource group.
     * @param loadBalancerName The name of the load balancer.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    LoadBalancers.prototype.deleteMethod = function (resourceGroupName, loadBalancerName, options) {
        return this.beginDeleteMethod(resourceGroupName, loadBalancerName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    LoadBalancers.prototype.get = function (resourceGroupName, loadBalancerName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            loadBalancerName: loadBalancerName,
            options: options
        }, getOperationSpec, callback);
    };
    /**
     * Creates or updates a load balancer.
     * @param resourceGroupName The name of the resource group.
     * @param loadBalancerName The name of the load balancer.
     * @param parameters Parameters supplied to the create or update load balancer operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.LoadBalancersCreateOrUpdateResponse>
     */
    LoadBalancers.prototype.createOrUpdate = function (resourceGroupName, loadBalancerName, parameters, options) {
        return this.beginCreateOrUpdate(resourceGroupName, loadBalancerName, parameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    LoadBalancers.prototype.updateTags = function (resourceGroupName, loadBalancerName, parameters, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            loadBalancerName: loadBalancerName,
            parameters: parameters,
            options: options
        }, updateTagsOperationSpec, callback);
    };
    LoadBalancers.prototype.listAll = function (options, callback) {
        return this.client.sendOperationRequest({
            options: options
        }, listAllOperationSpec, callback);
    };
    LoadBalancers.prototype.list = function (resourceGroupName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            options: options
        }, listOperationSpec, callback);
    };
    /**
     * Swaps VIPs between two load balancers.
     * @param location The region where load balancers are located at.
     * @param parameters Parameters that define which VIPs should be swapped.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    LoadBalancers.prototype.swapPublicIpAddresses = function (location, parameters, options) {
        return this.beginSwapPublicIpAddresses(location, parameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * List of inbound NAT rule port mappings.
     * @param groupName The name of the resource group.
     * @param loadBalancerName The name of the load balancer.
     * @param backendPoolName The name of the load balancer backend address pool.
     * @param parameters Query inbound NAT rule port mapping request.
     * @param [options] The optional parameters
     * @returns Promise<Models.LoadBalancersListInboundNatRulePortMappingsResponse>
     */
    LoadBalancers.prototype.listInboundNatRulePortMappings = function (groupName, loadBalancerName, backendPoolName, parameters, options) {
        return this.beginListInboundNatRulePortMappings(groupName, loadBalancerName, backendPoolName, parameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Deletes the specified load balancer.
     * @param resourceGroupName The name of the resource group.
     * @param loadBalancerName The name of the load balancer.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    LoadBalancers.prototype.beginDeleteMethod = function (resourceGroupName, loadBalancerName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            loadBalancerName: loadBalancerName,
            options: options
        }, beginDeleteMethodOperationSpec, options);
    };
    /**
     * Creates or updates a load balancer.
     * @param resourceGroupName The name of the resource group.
     * @param loadBalancerName The name of the load balancer.
     * @param parameters Parameters supplied to the create or update load balancer operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    LoadBalancers.prototype.beginCreateOrUpdate = function (resourceGroupName, loadBalancerName, parameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            loadBalancerName: loadBalancerName,
            parameters: parameters,
            options: options
        }, beginCreateOrUpdateOperationSpec, options);
    };
    /**
     * Swaps VIPs between two load balancers.
     * @param location The region where load balancers are located at.
     * @param parameters Parameters that define which VIPs should be swapped.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    LoadBalancers.prototype.beginSwapPublicIpAddresses = function (location, parameters, options) {
        return this.client.sendLRORequest({
            location: location,
            parameters: parameters,
            options: options
        }, beginSwapPublicIpAddressesOperationSpec, options);
    };
    /**
     * List of inbound NAT rule port mappings.
     * @param groupName The name of the resource group.
     * @param loadBalancerName The name of the load balancer.
     * @param backendPoolName The name of the load balancer backend address pool.
     * @param parameters Query inbound NAT rule port mapping request.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    LoadBalancers.prototype.beginListInboundNatRulePortMappings = function (groupName, loadBalancerName, backendPoolName, parameters, options) {
        return this.client.sendLRORequest({
            groupName: groupName,
            loadBalancerName: loadBalancerName,
            backendPoolName: backendPoolName,
            parameters: parameters,
            options: options
        }, beginListInboundNatRulePortMappingsOperationSpec, options);
    };
    LoadBalancers.prototype.listAllNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listAllNextOperationSpec, callback);
    };
    LoadBalancers.prototype.listNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listNextOperationSpec, callback);
    };
    return LoadBalancers;
}());
export { LoadBalancers };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var getOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/loadBalancers/{loadBalancerName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.loadBalancerName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0,
        Parameters.expand
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.LoadBalancer
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var updateTagsOperationSpec = {
    httpMethod: "PATCH",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/loadBalancers/{loadBalancerName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.loadBalancerName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.TagsObject), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.LoadBalancer
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listAllOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/providers/Microsoft.Network/loadBalancers",
    urlParameters: [
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.LoadBalancerListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/loadBalancers",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.LoadBalancerListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginDeleteMethodOperationSpec = {
    httpMethod: "DELETE",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/loadBalancers/{loadBalancerName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.loadBalancerName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {},
        202: {},
        204: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginCreateOrUpdateOperationSpec = {
    httpMethod: "PUT",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/loadBalancers/{loadBalancerName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.loadBalancerName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.LoadBalancer), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.LoadBalancer
        },
        201: {
            bodyMapper: Mappers.LoadBalancer
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginSwapPublicIpAddressesOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/providers/Microsoft.Network/locations/{location}/setLoadBalancerFrontendPublicIpAddresses",
    urlParameters: [
        Parameters.location0,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.LoadBalancerVipSwapRequest), { required: true })
    },
    responses: {
        200: {},
        202: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginListInboundNatRulePortMappingsOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{groupName}/providers/Microsoft.Network/loadBalancers/{loadBalancerName}/backendAddressPools/{backendPoolName}/queryInboundNatRulePortMapping",
    urlParameters: [
        Parameters.groupName,
        Parameters.loadBalancerName,
        Parameters.backendPoolName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.QueryInboundNatRulePortMappingRequest), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.BackendAddressInboundNatRulePortMappings
        },
        202: {
            bodyMapper: Mappers.BackendAddressInboundNatRulePortMappings
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listAllNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.LoadBalancerListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.LoadBalancerListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
//# sourceMappingURL=loadBalancers.js.map