import * as msRest from "@azure/ms-rest-js";
import * as msRestAzure from "@azure/ms-rest-azure-js";
import * as Models from "../models";
import { NetworkManagementClientContext } from "../networkManagementClientContext";
/** Class representing a RoutingIntentOperations. */
export declare class RoutingIntentOperations {
    private readonly client;
    /**
     * Create a RoutingIntentOperations.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    constructor(client: NetworkManagementClientContext);
    /**
     * Creates a RoutingIntent resource if it doesn't exist else updates the existing RoutingIntent.
     * @param resourceGroupName The resource group name of the RoutingIntent.
     * @param virtualHubName The name of the VirtualHub.
     * @param routingIntentName The name of the per VirtualHub singleton Routing Intent resource.
     * @param routingIntentParameters Parameters supplied to create or update RoutingIntent.
     * @param [options] The optional parameters
     * @returns Promise<Models.RoutingIntentCreateOrUpdateResponse>
     */
    createOrUpdate(resourceGroupName: string, virtualHubName: string, routingIntentName: string, routingIntentParameters: Models.RoutingIntent, options?: msRest.RequestOptionsBase): Promise<Models.RoutingIntentCreateOrUpdateResponse>;
    /**
     * Retrieves the details of a RoutingIntent.
     * @param resourceGroupName The resource group name of the RoutingIntent.
     * @param virtualHubName The name of the VirtualHub.
     * @param routingIntentName The name of the RoutingIntent.
     * @param [options] The optional parameters
     * @returns Promise<Models.RoutingIntentGetResponse>
     */
    get(resourceGroupName: string, virtualHubName: string, routingIntentName: string, options?: msRest.RequestOptionsBase): Promise<Models.RoutingIntentGetResponse>;
    /**
     * @param resourceGroupName The resource group name of the RoutingIntent.
     * @param virtualHubName The name of the VirtualHub.
     * @param routingIntentName The name of the RoutingIntent.
     * @param callback The callback
     */
    get(resourceGroupName: string, virtualHubName: string, routingIntentName: string, callback: msRest.ServiceCallback<Models.RoutingIntent>): void;
    /**
     * @param resourceGroupName The resource group name of the RoutingIntent.
     * @param virtualHubName The name of the VirtualHub.
     * @param routingIntentName The name of the RoutingIntent.
     * @param options The optional parameters
     * @param callback The callback
     */
    get(resourceGroupName: string, virtualHubName: string, routingIntentName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.RoutingIntent>): void;
    /**
     * Deletes a RoutingIntent.
     * @param resourceGroupName The resource group name of the RoutingIntent.
     * @param virtualHubName The name of the VirtualHub.
     * @param routingIntentName The name of the RoutingIntent.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    deleteMethod(resourceGroupName: string, virtualHubName: string, routingIntentName: string, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * Retrieves the details of all RoutingIntent child resources of the VirtualHub.
     * @param resourceGroupName The resource group name of the VirtualHub.
     * @param virtualHubName The name of the VirtualHub.
     * @param [options] The optional parameters
     * @returns Promise<Models.RoutingIntentListResponse>
     */
    list(resourceGroupName: string, virtualHubName: string, options?: msRest.RequestOptionsBase): Promise<Models.RoutingIntentListResponse>;
    /**
     * @param resourceGroupName The resource group name of the VirtualHub.
     * @param virtualHubName The name of the VirtualHub.
     * @param callback The callback
     */
    list(resourceGroupName: string, virtualHubName: string, callback: msRest.ServiceCallback<Models.ListRoutingIntentResult>): void;
    /**
     * @param resourceGroupName The resource group name of the VirtualHub.
     * @param virtualHubName The name of the VirtualHub.
     * @param options The optional parameters
     * @param callback The callback
     */
    list(resourceGroupName: string, virtualHubName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.ListRoutingIntentResult>): void;
    /**
     * Creates a RoutingIntent resource if it doesn't exist else updates the existing RoutingIntent.
     * @param resourceGroupName The resource group name of the RoutingIntent.
     * @param virtualHubName The name of the VirtualHub.
     * @param routingIntentName The name of the per VirtualHub singleton Routing Intent resource.
     * @param routingIntentParameters Parameters supplied to create or update RoutingIntent.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginCreateOrUpdate(resourceGroupName: string, virtualHubName: string, routingIntentName: string, routingIntentParameters: Models.RoutingIntent, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
    /**
     * Deletes a RoutingIntent.
     * @param resourceGroupName The resource group name of the RoutingIntent.
     * @param virtualHubName The name of the VirtualHub.
     * @param routingIntentName The name of the RoutingIntent.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginDeleteMethod(resourceGroupName: string, virtualHubName: string, routingIntentName: string, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
    /**
     * Retrieves the details of all RoutingIntent child resources of the VirtualHub.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.RoutingIntentListNextResponse>
     */
    listNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.RoutingIntentListNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.ListRoutingIntentResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.ListRoutingIntentResult>): void;
}
//# sourceMappingURL=routingIntentOperations.d.ts.map