/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import { __assign } from "tslib";
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/routingIntentOperationsMappers";
import * as Parameters from "../models/parameters";
/** Class representing a RoutingIntentOperations. */
var RoutingIntentOperations = /** @class */ (function () {
    /**
     * Create a RoutingIntentOperations.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    function RoutingIntentOperations(client) {
        this.client = client;
    }
    /**
     * Creates a RoutingIntent resource if it doesn't exist else updates the existing RoutingIntent.
     * @param resourceGroupName The resource group name of the RoutingIntent.
     * @param virtualHubName The name of the VirtualHub.
     * @param routingIntentName The name of the per VirtualHub singleton Routing Intent resource.
     * @param routingIntentParameters Parameters supplied to create or update RoutingIntent.
     * @param [options] The optional parameters
     * @returns Promise<Models.RoutingIntentCreateOrUpdateResponse>
     */
    RoutingIntentOperations.prototype.createOrUpdate = function (resourceGroupName, virtualHubName, routingIntentName, routingIntentParameters, options) {
        return this.beginCreateOrUpdate(resourceGroupName, virtualHubName, routingIntentName, routingIntentParameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    RoutingIntentOperations.prototype.get = function (resourceGroupName, virtualHubName, routingIntentName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            virtualHubName: virtualHubName,
            routingIntentName: routingIntentName,
            options: options
        }, getOperationSpec, callback);
    };
    /**
     * Deletes a RoutingIntent.
     * @param resourceGroupName The resource group name of the RoutingIntent.
     * @param virtualHubName The name of the VirtualHub.
     * @param routingIntentName The name of the RoutingIntent.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    RoutingIntentOperations.prototype.deleteMethod = function (resourceGroupName, virtualHubName, routingIntentName, options) {
        return this.beginDeleteMethod(resourceGroupName, virtualHubName, routingIntentName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    RoutingIntentOperations.prototype.list = function (resourceGroupName, virtualHubName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            virtualHubName: virtualHubName,
            options: options
        }, listOperationSpec, callback);
    };
    /**
     * Creates a RoutingIntent resource if it doesn't exist else updates the existing RoutingIntent.
     * @param resourceGroupName The resource group name of the RoutingIntent.
     * @param virtualHubName The name of the VirtualHub.
     * @param routingIntentName The name of the per VirtualHub singleton Routing Intent resource.
     * @param routingIntentParameters Parameters supplied to create or update RoutingIntent.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    RoutingIntentOperations.prototype.beginCreateOrUpdate = function (resourceGroupName, virtualHubName, routingIntentName, routingIntentParameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            virtualHubName: virtualHubName,
            routingIntentName: routingIntentName,
            routingIntentParameters: routingIntentParameters,
            options: options
        }, beginCreateOrUpdateOperationSpec, options);
    };
    /**
     * Deletes a RoutingIntent.
     * @param resourceGroupName The resource group name of the RoutingIntent.
     * @param virtualHubName The name of the VirtualHub.
     * @param routingIntentName The name of the RoutingIntent.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    RoutingIntentOperations.prototype.beginDeleteMethod = function (resourceGroupName, virtualHubName, routingIntentName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            virtualHubName: virtualHubName,
            routingIntentName: routingIntentName,
            options: options
        }, beginDeleteMethodOperationSpec, options);
    };
    RoutingIntentOperations.prototype.listNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listNextOperationSpec, callback);
    };
    return RoutingIntentOperations;
}());
export { RoutingIntentOperations };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var getOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualHubs/{virtualHubName}/routingIntent/{routingIntentName}",
    urlParameters: [
        Parameters.subscriptionId,
        Parameters.resourceGroupName,
        Parameters.virtualHubName,
        Parameters.routingIntentName
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.RoutingIntent
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualHubs/{virtualHubName}/routingIntent",
    urlParameters: [
        Parameters.subscriptionId,
        Parameters.resourceGroupName,
        Parameters.virtualHubName
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ListRoutingIntentResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginCreateOrUpdateOperationSpec = {
    httpMethod: "PUT",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualHubs/{virtualHubName}/routingIntent/{routingIntentName}",
    urlParameters: [
        Parameters.subscriptionId,
        Parameters.resourceGroupName,
        Parameters.virtualHubName,
        Parameters.routingIntentName
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "routingIntentParameters",
        mapper: __assign(__assign({}, Mappers.RoutingIntent), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.RoutingIntent
        },
        201: {
            bodyMapper: Mappers.RoutingIntent
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginDeleteMethodOperationSpec = {
    httpMethod: "DELETE",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualHubs/{virtualHubName}/routingIntent/{routingIntentName}",
    urlParameters: [
        Parameters.subscriptionId,
        Parameters.resourceGroupName,
        Parameters.virtualHubName,
        Parameters.routingIntentName
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {},
        202: {},
        204: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ListRoutingIntentResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
//# sourceMappingURL=routingIntentOperations.js.map