/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import { __assign } from "tslib";
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/serviceEndpointPolicyDefinitionsMappers";
import * as Parameters from "../models/parameters";
/** Class representing a ServiceEndpointPolicyDefinitions. */
var ServiceEndpointPolicyDefinitions = /** @class */ (function () {
    /**
     * Create a ServiceEndpointPolicyDefinitions.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    function ServiceEndpointPolicyDefinitions(client) {
        this.client = client;
    }
    /**
     * Deletes the specified ServiceEndpoint policy definitions.
     * @param resourceGroupName The name of the resource group.
     * @param serviceEndpointPolicyName The name of the Service Endpoint Policy.
     * @param serviceEndpointPolicyDefinitionName The name of the service endpoint policy definition.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    ServiceEndpointPolicyDefinitions.prototype.deleteMethod = function (resourceGroupName, serviceEndpointPolicyName, serviceEndpointPolicyDefinitionName, options) {
        return this.beginDeleteMethod(resourceGroupName, serviceEndpointPolicyName, serviceEndpointPolicyDefinitionName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    ServiceEndpointPolicyDefinitions.prototype.get = function (resourceGroupName, serviceEndpointPolicyName, serviceEndpointPolicyDefinitionName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            serviceEndpointPolicyName: serviceEndpointPolicyName,
            serviceEndpointPolicyDefinitionName: serviceEndpointPolicyDefinitionName,
            options: options
        }, getOperationSpec, callback);
    };
    /**
     * Creates or updates a service endpoint policy definition in the specified service endpoint
     * policy.
     * @param resourceGroupName The name of the resource group.
     * @param serviceEndpointPolicyName The name of the service endpoint policy.
     * @param serviceEndpointPolicyDefinitionName The name of the service endpoint policy definition
     * name.
     * @param serviceEndpointPolicyDefinitions Parameters supplied to the create or update service
     * endpoint policy operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.ServiceEndpointPolicyDefinitionsCreateOrUpdateResponse>
     */
    ServiceEndpointPolicyDefinitions.prototype.createOrUpdate = function (resourceGroupName, serviceEndpointPolicyName, serviceEndpointPolicyDefinitionName, serviceEndpointPolicyDefinitions, options) {
        return this.beginCreateOrUpdate(resourceGroupName, serviceEndpointPolicyName, serviceEndpointPolicyDefinitionName, serviceEndpointPolicyDefinitions, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    ServiceEndpointPolicyDefinitions.prototype.listByResourceGroup = function (resourceGroupName, serviceEndpointPolicyName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            serviceEndpointPolicyName: serviceEndpointPolicyName,
            options: options
        }, listByResourceGroupOperationSpec, callback);
    };
    /**
     * Deletes the specified ServiceEndpoint policy definitions.
     * @param resourceGroupName The name of the resource group.
     * @param serviceEndpointPolicyName The name of the Service Endpoint Policy.
     * @param serviceEndpointPolicyDefinitionName The name of the service endpoint policy definition.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    ServiceEndpointPolicyDefinitions.prototype.beginDeleteMethod = function (resourceGroupName, serviceEndpointPolicyName, serviceEndpointPolicyDefinitionName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            serviceEndpointPolicyName: serviceEndpointPolicyName,
            serviceEndpointPolicyDefinitionName: serviceEndpointPolicyDefinitionName,
            options: options
        }, beginDeleteMethodOperationSpec, options);
    };
    /**
     * Creates or updates a service endpoint policy definition in the specified service endpoint
     * policy.
     * @param resourceGroupName The name of the resource group.
     * @param serviceEndpointPolicyName The name of the service endpoint policy.
     * @param serviceEndpointPolicyDefinitionName The name of the service endpoint policy definition
     * name.
     * @param serviceEndpointPolicyDefinitions Parameters supplied to the create or update service
     * endpoint policy operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    ServiceEndpointPolicyDefinitions.prototype.beginCreateOrUpdate = function (resourceGroupName, serviceEndpointPolicyName, serviceEndpointPolicyDefinitionName, serviceEndpointPolicyDefinitions, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            serviceEndpointPolicyName: serviceEndpointPolicyName,
            serviceEndpointPolicyDefinitionName: serviceEndpointPolicyDefinitionName,
            serviceEndpointPolicyDefinitions: serviceEndpointPolicyDefinitions,
            options: options
        }, beginCreateOrUpdateOperationSpec, options);
    };
    ServiceEndpointPolicyDefinitions.prototype.listByResourceGroupNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listByResourceGroupNextOperationSpec, callback);
    };
    return ServiceEndpointPolicyDefinitions;
}());
export { ServiceEndpointPolicyDefinitions };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var getOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/serviceEndpointPolicies/{serviceEndpointPolicyName}/serviceEndpointPolicyDefinitions/{serviceEndpointPolicyDefinitionName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.serviceEndpointPolicyName,
        Parameters.serviceEndpointPolicyDefinitionName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ServiceEndpointPolicyDefinition
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listByResourceGroupOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/serviceEndpointPolicies/{serviceEndpointPolicyName}/serviceEndpointPolicyDefinitions",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.serviceEndpointPolicyName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ServiceEndpointPolicyDefinitionListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginDeleteMethodOperationSpec = {
    httpMethod: "DELETE",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/serviceEndpointPolicies/{serviceEndpointPolicyName}/serviceEndpointPolicyDefinitions/{serviceEndpointPolicyDefinitionName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.serviceEndpointPolicyName,
        Parameters.serviceEndpointPolicyDefinitionName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {},
        202: {},
        204: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginCreateOrUpdateOperationSpec = {
    httpMethod: "PUT",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/serviceEndpointPolicies/{serviceEndpointPolicyName}/serviceEndpointPolicyDefinitions/{serviceEndpointPolicyDefinitionName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.serviceEndpointPolicyName,
        Parameters.serviceEndpointPolicyDefinitionName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "serviceEndpointPolicyDefinitions",
        mapper: __assign(__assign({}, Mappers.ServiceEndpointPolicyDefinition), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.ServiceEndpointPolicyDefinition
        },
        201: {
            bodyMapper: Mappers.ServiceEndpointPolicyDefinition
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listByResourceGroupNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ServiceEndpointPolicyDefinitionListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
//# sourceMappingURL=serviceEndpointPolicyDefinitions.js.map