/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import { __assign } from "tslib";
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/virtualNetworkGatewayConnectionsMappers";
import * as Parameters from "../models/parameters";
/** Class representing a VirtualNetworkGatewayConnections. */
var VirtualNetworkGatewayConnections = /** @class */ (function () {
    /**
     * Create a VirtualNetworkGatewayConnections.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    function VirtualNetworkGatewayConnections(client) {
        this.client = client;
    }
    /**
     * Creates or updates a virtual network gateway connection in the specified resource group.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayConnectionName The name of the virtual network gateway connection.
     * @param parameters Parameters supplied to the create or update virtual network gateway connection
     * operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualNetworkGatewayConnectionsCreateOrUpdateResponse>
     */
    VirtualNetworkGatewayConnections.prototype.createOrUpdate = function (resourceGroupName, virtualNetworkGatewayConnectionName, parameters, options) {
        return this.beginCreateOrUpdate(resourceGroupName, virtualNetworkGatewayConnectionName, parameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    VirtualNetworkGatewayConnections.prototype.get = function (resourceGroupName, virtualNetworkGatewayConnectionName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            virtualNetworkGatewayConnectionName: virtualNetworkGatewayConnectionName,
            options: options
        }, getOperationSpec, callback);
    };
    /**
     * Deletes the specified virtual network Gateway connection.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayConnectionName The name of the virtual network gateway connection.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    VirtualNetworkGatewayConnections.prototype.deleteMethod = function (resourceGroupName, virtualNetworkGatewayConnectionName, options) {
        return this.beginDeleteMethod(resourceGroupName, virtualNetworkGatewayConnectionName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Updates a virtual network gateway connection tags.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayConnectionName The name of the virtual network gateway connection.
     * @param parameters Parameters supplied to update virtual network gateway connection tags.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualNetworkGatewayConnectionsUpdateTagsResponse>
     */
    VirtualNetworkGatewayConnections.prototype.updateTags = function (resourceGroupName, virtualNetworkGatewayConnectionName, parameters, options) {
        return this.beginUpdateTags(resourceGroupName, virtualNetworkGatewayConnectionName, parameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * The Put VirtualNetworkGatewayConnectionSharedKey operation sets the virtual network gateway
     * connection shared key for passed virtual network gateway connection in the specified resource
     * group through Network resource provider.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayConnectionName The virtual network gateway connection name.
     * @param parameters Parameters supplied to the Begin Set Virtual Network Gateway connection Shared
     * key operation throughNetwork resource provider.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualNetworkGatewayConnectionsSetSharedKeyResponse>
     */
    VirtualNetworkGatewayConnections.prototype.setSharedKey = function (resourceGroupName, virtualNetworkGatewayConnectionName, parameters, options) {
        return this.beginSetSharedKey(resourceGroupName, virtualNetworkGatewayConnectionName, parameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    VirtualNetworkGatewayConnections.prototype.getSharedKey = function (resourceGroupName, virtualNetworkGatewayConnectionName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            virtualNetworkGatewayConnectionName: virtualNetworkGatewayConnectionName,
            options: options
        }, getSharedKeyOperationSpec, callback);
    };
    VirtualNetworkGatewayConnections.prototype.list = function (resourceGroupName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            options: options
        }, listOperationSpec, callback);
    };
    /**
     * The VirtualNetworkGatewayConnectionResetSharedKey operation resets the virtual network gateway
     * connection shared key for passed virtual network gateway connection in the specified resource
     * group through Network resource provider.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayConnectionName The virtual network gateway connection reset shared
     * key Name.
     * @param parameters Parameters supplied to the begin reset virtual network gateway connection
     * shared key operation through network resource provider.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualNetworkGatewayConnectionsResetSharedKeyResponse>
     */
    VirtualNetworkGatewayConnections.prototype.resetSharedKey = function (resourceGroupName, virtualNetworkGatewayConnectionName, parameters, options) {
        return this.beginResetSharedKey(resourceGroupName, virtualNetworkGatewayConnectionName, parameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Starts packet capture on virtual network gateway connection in the specified resource group.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayConnectionName The name of the virtual network gateway connection.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualNetworkGatewayConnectionsStartPacketCaptureResponse>
     */
    VirtualNetworkGatewayConnections.prototype.startPacketCapture = function (resourceGroupName, virtualNetworkGatewayConnectionName, options) {
        return this.beginStartPacketCapture(resourceGroupName, virtualNetworkGatewayConnectionName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Stops packet capture on virtual network gateway connection in the specified resource group.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayConnectionName The name of the virtual network gateway Connection.
     * @param parameters Virtual network gateway packet capture parameters supplied to stop packet
     * capture on gateway connection.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualNetworkGatewayConnectionsStopPacketCaptureResponse>
     */
    VirtualNetworkGatewayConnections.prototype.stopPacketCapture = function (resourceGroupName, virtualNetworkGatewayConnectionName, parameters, options) {
        return this.beginStopPacketCapture(resourceGroupName, virtualNetworkGatewayConnectionName, parameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Lists IKE Security Associations for the virtual network gateway connection in the specified
     * resource group.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayConnectionName The name of the virtual network gateway Connection.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualNetworkGatewayConnectionsGetIkeSasResponse>
     */
    VirtualNetworkGatewayConnections.prototype.getIkeSas = function (resourceGroupName, virtualNetworkGatewayConnectionName, options) {
        return this.beginGetIkeSas(resourceGroupName, virtualNetworkGatewayConnectionName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Resets the virtual network gateway connection specified.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayConnectionName The name of the virtual network gateway Connection.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    VirtualNetworkGatewayConnections.prototype.resetConnection = function (resourceGroupName, virtualNetworkGatewayConnectionName, options) {
        return this.beginResetConnection(resourceGroupName, virtualNetworkGatewayConnectionName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Creates or updates a virtual network gateway connection in the specified resource group.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayConnectionName The name of the virtual network gateway connection.
     * @param parameters Parameters supplied to the create or update virtual network gateway connection
     * operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    VirtualNetworkGatewayConnections.prototype.beginCreateOrUpdate = function (resourceGroupName, virtualNetworkGatewayConnectionName, parameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            virtualNetworkGatewayConnectionName: virtualNetworkGatewayConnectionName,
            parameters: parameters,
            options: options
        }, beginCreateOrUpdateOperationSpec, options);
    };
    /**
     * Deletes the specified virtual network Gateway connection.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayConnectionName The name of the virtual network gateway connection.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    VirtualNetworkGatewayConnections.prototype.beginDeleteMethod = function (resourceGroupName, virtualNetworkGatewayConnectionName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            virtualNetworkGatewayConnectionName: virtualNetworkGatewayConnectionName,
            options: options
        }, beginDeleteMethodOperationSpec, options);
    };
    /**
     * Updates a virtual network gateway connection tags.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayConnectionName The name of the virtual network gateway connection.
     * @param parameters Parameters supplied to update virtual network gateway connection tags.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    VirtualNetworkGatewayConnections.prototype.beginUpdateTags = function (resourceGroupName, virtualNetworkGatewayConnectionName, parameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            virtualNetworkGatewayConnectionName: virtualNetworkGatewayConnectionName,
            parameters: parameters,
            options: options
        }, beginUpdateTagsOperationSpec, options);
    };
    /**
     * The Put VirtualNetworkGatewayConnectionSharedKey operation sets the virtual network gateway
     * connection shared key for passed virtual network gateway connection in the specified resource
     * group through Network resource provider.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayConnectionName The virtual network gateway connection name.
     * @param parameters Parameters supplied to the Begin Set Virtual Network Gateway connection Shared
     * key operation throughNetwork resource provider.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    VirtualNetworkGatewayConnections.prototype.beginSetSharedKey = function (resourceGroupName, virtualNetworkGatewayConnectionName, parameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            virtualNetworkGatewayConnectionName: virtualNetworkGatewayConnectionName,
            parameters: parameters,
            options: options
        }, beginSetSharedKeyOperationSpec, options);
    };
    /**
     * The VirtualNetworkGatewayConnectionResetSharedKey operation resets the virtual network gateway
     * connection shared key for passed virtual network gateway connection in the specified resource
     * group through Network resource provider.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayConnectionName The virtual network gateway connection reset shared
     * key Name.
     * @param parameters Parameters supplied to the begin reset virtual network gateway connection
     * shared key operation through network resource provider.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    VirtualNetworkGatewayConnections.prototype.beginResetSharedKey = function (resourceGroupName, virtualNetworkGatewayConnectionName, parameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            virtualNetworkGatewayConnectionName: virtualNetworkGatewayConnectionName,
            parameters: parameters,
            options: options
        }, beginResetSharedKeyOperationSpec, options);
    };
    /**
     * Starts packet capture on virtual network gateway connection in the specified resource group.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayConnectionName The name of the virtual network gateway connection.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    VirtualNetworkGatewayConnections.prototype.beginStartPacketCapture = function (resourceGroupName, virtualNetworkGatewayConnectionName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            virtualNetworkGatewayConnectionName: virtualNetworkGatewayConnectionName,
            options: options
        }, beginStartPacketCaptureOperationSpec, options);
    };
    /**
     * Stops packet capture on virtual network gateway connection in the specified resource group.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayConnectionName The name of the virtual network gateway Connection.
     * @param parameters Virtual network gateway packet capture parameters supplied to stop packet
     * capture on gateway connection.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    VirtualNetworkGatewayConnections.prototype.beginStopPacketCapture = function (resourceGroupName, virtualNetworkGatewayConnectionName, parameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            virtualNetworkGatewayConnectionName: virtualNetworkGatewayConnectionName,
            parameters: parameters,
            options: options
        }, beginStopPacketCaptureOperationSpec, options);
    };
    /**
     * Lists IKE Security Associations for the virtual network gateway connection in the specified
     * resource group.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayConnectionName The name of the virtual network gateway Connection.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    VirtualNetworkGatewayConnections.prototype.beginGetIkeSas = function (resourceGroupName, virtualNetworkGatewayConnectionName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            virtualNetworkGatewayConnectionName: virtualNetworkGatewayConnectionName,
            options: options
        }, beginGetIkeSasOperationSpec, options);
    };
    /**
     * Resets the virtual network gateway connection specified.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayConnectionName The name of the virtual network gateway Connection.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    VirtualNetworkGatewayConnections.prototype.beginResetConnection = function (resourceGroupName, virtualNetworkGatewayConnectionName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            virtualNetworkGatewayConnectionName: virtualNetworkGatewayConnectionName,
            options: options
        }, beginResetConnectionOperationSpec, options);
    };
    VirtualNetworkGatewayConnections.prototype.listNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listNextOperationSpec, callback);
    };
    return VirtualNetworkGatewayConnections;
}());
export { VirtualNetworkGatewayConnections };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var getOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/connections/{virtualNetworkGatewayConnectionName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.virtualNetworkGatewayConnectionName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.VirtualNetworkGatewayConnection
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var getSharedKeyOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/connections/{virtualNetworkGatewayConnectionName}/sharedkey",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.virtualNetworkGatewayConnectionName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ConnectionSharedKey
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/connections",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.VirtualNetworkGatewayConnectionListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginCreateOrUpdateOperationSpec = {
    httpMethod: "PUT",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/connections/{virtualNetworkGatewayConnectionName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.virtualNetworkGatewayConnectionName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.VirtualNetworkGatewayConnection), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.VirtualNetworkGatewayConnection
        },
        201: {
            bodyMapper: Mappers.VirtualNetworkGatewayConnection
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginDeleteMethodOperationSpec = {
    httpMethod: "DELETE",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/connections/{virtualNetworkGatewayConnectionName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.virtualNetworkGatewayConnectionName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {},
        202: {},
        204: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginUpdateTagsOperationSpec = {
    httpMethod: "PATCH",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/connections/{virtualNetworkGatewayConnectionName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.virtualNetworkGatewayConnectionName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.TagsObject), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.VirtualNetworkGatewayConnection
        },
        202: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginSetSharedKeyOperationSpec = {
    httpMethod: "PUT",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/connections/{virtualNetworkGatewayConnectionName}/sharedkey",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.virtualNetworkGatewayConnectionName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.ConnectionSharedKey), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.ConnectionSharedKey
        },
        201: {
            bodyMapper: Mappers.ConnectionSharedKey
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginResetSharedKeyOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/connections/{virtualNetworkGatewayConnectionName}/sharedkey/reset",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.virtualNetworkGatewayConnectionName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.ConnectionResetSharedKey), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.ConnectionResetSharedKey
        },
        202: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginStartPacketCaptureOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/connections/{virtualNetworkGatewayConnectionName}/startPacketCapture",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.virtualNetworkGatewayConnectionName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: [
            "options",
            "parameters"
        ],
        mapper: Mappers.VpnPacketCaptureStartParameters
    },
    responses: {
        200: {
            bodyMapper: {
                serializedName: "parsedResponse",
                type: {
                    name: "String"
                }
            }
        },
        202: {},
        default: {
            bodyMapper: Mappers.ErrorModel
        }
    },
    serializer: serializer
};
var beginStopPacketCaptureOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/connections/{virtualNetworkGatewayConnectionName}/stopPacketCapture",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.virtualNetworkGatewayConnectionName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.VpnPacketCaptureStopParameters), { required: true })
    },
    responses: {
        200: {
            bodyMapper: {
                serializedName: "parsedResponse",
                type: {
                    name: "String"
                }
            }
        },
        202: {},
        default: {
            bodyMapper: Mappers.ErrorModel
        }
    },
    serializer: serializer
};
var beginGetIkeSasOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/connections/{virtualNetworkGatewayConnectionName}/getikesas",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.virtualNetworkGatewayConnectionName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: {
                serializedName: "parsedResponse",
                type: {
                    name: "String"
                }
            }
        },
        202: {},
        default: {
            bodyMapper: Mappers.ErrorResponse
        }
    },
    serializer: serializer
};
var beginResetConnectionOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/connections/{virtualNetworkGatewayConnectionName}/resetconnection",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.virtualNetworkGatewayConnectionName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        202: {},
        default: {
            bodyMapper: Mappers.ErrorResponse
        }
    },
    serializer: serializer
};
var listNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.VirtualNetworkGatewayConnectionListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
//# sourceMappingURL=virtualNetworkGatewayConnections.js.map