/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import { __assign } from "tslib";
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/virtualNetworkGatewayNatRulesMappers";
import * as Parameters from "../models/parameters";
/** Class representing a VirtualNetworkGatewayNatRules. */
var VirtualNetworkGatewayNatRules = /** @class */ (function () {
    /**
     * Create a VirtualNetworkGatewayNatRules.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    function VirtualNetworkGatewayNatRules(client) {
        this.client = client;
    }
    VirtualNetworkGatewayNatRules.prototype.get = function (resourceGroupName, virtualNetworkGatewayName, natRuleName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            virtualNetworkGatewayName: virtualNetworkGatewayName,
            natRuleName: natRuleName,
            options: options
        }, getOperationSpec, callback);
    };
    /**
     * Creates a nat rule to a scalable virtual network gateway if it doesn't exist else updates the
     * existing nat rules.
     * @param resourceGroupName The resource group name of the Virtual Network Gateway.
     * @param virtualNetworkGatewayName The name of the gateway.
     * @param natRuleName The name of the nat rule.
     * @param natRuleParameters Parameters supplied to create or Update a Nat Rule.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualNetworkGatewayNatRulesCreateOrUpdateResponse>
     */
    VirtualNetworkGatewayNatRules.prototype.createOrUpdate = function (resourceGroupName, virtualNetworkGatewayName, natRuleName, natRuleParameters, options) {
        return this.beginCreateOrUpdate(resourceGroupName, virtualNetworkGatewayName, natRuleName, natRuleParameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Deletes a nat rule.
     * @param resourceGroupName The resource group name of the Virtual Network Gateway.
     * @param virtualNetworkGatewayName The name of the gateway.
     * @param natRuleName The name of the nat rule.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    VirtualNetworkGatewayNatRules.prototype.deleteMethod = function (resourceGroupName, virtualNetworkGatewayName, natRuleName, options) {
        return this.beginDeleteMethod(resourceGroupName, virtualNetworkGatewayName, natRuleName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    VirtualNetworkGatewayNatRules.prototype.listByVirtualNetworkGateway = function (resourceGroupName, virtualNetworkGatewayName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            virtualNetworkGatewayName: virtualNetworkGatewayName,
            options: options
        }, listByVirtualNetworkGatewayOperationSpec, callback);
    };
    /**
     * Creates a nat rule to a scalable virtual network gateway if it doesn't exist else updates the
     * existing nat rules.
     * @param resourceGroupName The resource group name of the Virtual Network Gateway.
     * @param virtualNetworkGatewayName The name of the gateway.
     * @param natRuleName The name of the nat rule.
     * @param natRuleParameters Parameters supplied to create or Update a Nat Rule.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    VirtualNetworkGatewayNatRules.prototype.beginCreateOrUpdate = function (resourceGroupName, virtualNetworkGatewayName, natRuleName, natRuleParameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            virtualNetworkGatewayName: virtualNetworkGatewayName,
            natRuleName: natRuleName,
            natRuleParameters: natRuleParameters,
            options: options
        }, beginCreateOrUpdateOperationSpec, options);
    };
    /**
     * Deletes a nat rule.
     * @param resourceGroupName The resource group name of the Virtual Network Gateway.
     * @param virtualNetworkGatewayName The name of the gateway.
     * @param natRuleName The name of the nat rule.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    VirtualNetworkGatewayNatRules.prototype.beginDeleteMethod = function (resourceGroupName, virtualNetworkGatewayName, natRuleName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            virtualNetworkGatewayName: virtualNetworkGatewayName,
            natRuleName: natRuleName,
            options: options
        }, beginDeleteMethodOperationSpec, options);
    };
    VirtualNetworkGatewayNatRules.prototype.listByVirtualNetworkGatewayNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listByVirtualNetworkGatewayNextOperationSpec, callback);
    };
    return VirtualNetworkGatewayNatRules;
}());
export { VirtualNetworkGatewayNatRules };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var getOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualNetworkGateways/{virtualNetworkGatewayName}/natRules/{natRuleName}",
    urlParameters: [
        Parameters.subscriptionId,
        Parameters.resourceGroupName,
        Parameters.virtualNetworkGatewayName,
        Parameters.natRuleName
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.VirtualNetworkGatewayNatRule
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listByVirtualNetworkGatewayOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualNetworkGateways/{virtualNetworkGatewayName}/natRules",
    urlParameters: [
        Parameters.subscriptionId,
        Parameters.resourceGroupName,
        Parameters.virtualNetworkGatewayName
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ListVirtualNetworkGatewayNatRulesResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginCreateOrUpdateOperationSpec = {
    httpMethod: "PUT",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualNetworkGateways/{virtualNetworkGatewayName}/natRules/{natRuleName}",
    urlParameters: [
        Parameters.subscriptionId,
        Parameters.resourceGroupName,
        Parameters.virtualNetworkGatewayName,
        Parameters.natRuleName
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "natRuleParameters",
        mapper: __assign(__assign({}, Mappers.VirtualNetworkGatewayNatRule), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.VirtualNetworkGatewayNatRule
        },
        201: {
            bodyMapper: Mappers.VirtualNetworkGatewayNatRule
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginDeleteMethodOperationSpec = {
    httpMethod: "DELETE",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualNetworkGateways/{virtualNetworkGatewayName}/natRules/{natRuleName}",
    urlParameters: [
        Parameters.subscriptionId,
        Parameters.resourceGroupName,
        Parameters.virtualNetworkGatewayName,
        Parameters.natRuleName
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {},
        202: {},
        204: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listByVirtualNetworkGatewayNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ListVirtualNetworkGatewayNatRulesResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
//# sourceMappingURL=virtualNetworkGatewayNatRules.js.map