/*
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Licensed under the MIT License. See License.txt in the project root for
 * license information.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import { __assign } from "tslib";
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/recordSetsMappers";
import * as Parameters from "../models/parameters";
/** Class representing a RecordSets. */
var RecordSets = /** @class */ (function () {
    /**
     * Create a RecordSets.
     * @param {PrivateDnsManagementClientContext} client Reference to the service client.
     */
    function RecordSets(client) {
        this.client = client;
    }
    RecordSets.prototype.createOrUpdate = function (resourceGroupName, privateZoneName, recordType, relativeRecordSetName, parameters, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            privateZoneName: privateZoneName,
            recordType: recordType,
            relativeRecordSetName: relativeRecordSetName,
            parameters: parameters,
            options: options
        }, createOrUpdateOperationSpec, callback);
    };
    RecordSets.prototype.update = function (resourceGroupName, privateZoneName, recordType, relativeRecordSetName, parameters, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            privateZoneName: privateZoneName,
            recordType: recordType,
            relativeRecordSetName: relativeRecordSetName,
            parameters: parameters,
            options: options
        }, updateOperationSpec, callback);
    };
    RecordSets.prototype.deleteMethod = function (resourceGroupName, privateZoneName, recordType, relativeRecordSetName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            privateZoneName: privateZoneName,
            recordType: recordType,
            relativeRecordSetName: relativeRecordSetName,
            options: options
        }, deleteMethodOperationSpec, callback);
    };
    RecordSets.prototype.get = function (resourceGroupName, privateZoneName, recordType, relativeRecordSetName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            privateZoneName: privateZoneName,
            recordType: recordType,
            relativeRecordSetName: relativeRecordSetName,
            options: options
        }, getOperationSpec, callback);
    };
    RecordSets.prototype.listByType = function (resourceGroupName, privateZoneName, recordType, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            privateZoneName: privateZoneName,
            recordType: recordType,
            options: options
        }, listByTypeOperationSpec, callback);
    };
    RecordSets.prototype.list = function (resourceGroupName, privateZoneName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            privateZoneName: privateZoneName,
            options: options
        }, listOperationSpec, callback);
    };
    RecordSets.prototype.listByTypeNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listByTypeNextOperationSpec, callback);
    };
    RecordSets.prototype.listNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listNextOperationSpec, callback);
    };
    return RecordSets;
}());
export { RecordSets };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var createOrUpdateOperationSpec = {
    httpMethod: "PUT",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/privateDnsZones/{privateZoneName}/{recordType}/{relativeRecordSetName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.privateZoneName,
        Parameters.recordType,
        Parameters.relativeRecordSetName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion
    ],
    headerParameters: [
        Parameters.ifMatch,
        Parameters.ifNoneMatch,
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.RecordSet), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.RecordSet
        },
        201: {
            bodyMapper: Mappers.RecordSet
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var updateOperationSpec = {
    httpMethod: "PATCH",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/privateDnsZones/{privateZoneName}/{recordType}/{relativeRecordSetName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.privateZoneName,
        Parameters.recordType,
        Parameters.relativeRecordSetName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion
    ],
    headerParameters: [
        Parameters.ifMatch,
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.RecordSet), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.RecordSet
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var deleteMethodOperationSpec = {
    httpMethod: "DELETE",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/privateDnsZones/{privateZoneName}/{recordType}/{relativeRecordSetName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.privateZoneName,
        Parameters.recordType,
        Parameters.relativeRecordSetName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion
    ],
    headerParameters: [
        Parameters.ifMatch,
        Parameters.acceptLanguage
    ],
    responses: {
        200: {},
        204: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var getOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/privateDnsZones/{privateZoneName}/{recordType}/{relativeRecordSetName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.privateZoneName,
        Parameters.recordType,
        Parameters.relativeRecordSetName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.RecordSet
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listByTypeOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/privateDnsZones/{privateZoneName}/{recordType}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.privateZoneName,
        Parameters.recordType,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.top,
        Parameters.recordsetnamesuffix,
        Parameters.apiVersion
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.RecordSetListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/privateDnsZones/{privateZoneName}/ALL",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.privateZoneName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.top,
        Parameters.recordsetnamesuffix,
        Parameters.apiVersion
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.RecordSetListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listByTypeNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.RecordSetListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.RecordSetListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
//# sourceMappingURL=recordSets.js.map